@@ -33,7 +33,7 @@ Fsdb - a flat-text database for shell scripting
 
 
 =cut
-our $VERSION = '2.62';
+our $VERSION = '2.63';
 
 =head1 SYNOPSIS
 
@@ -234,36 +234,31 @@ L<http://www.isi.edu/~johnh/SOFTWARE/FSDB/index.html>.
 
 =head1 WHAT'S NEW
 
-=head2 2.62, 2016-11-29
-A new L<yaml_to_db> and other minor improvements.
+=head2 2.63, 2017-02-03
+Re-add some features supposedly in 2.62 but not, and add more --header options.
 
 =over 4
 
 =item ENHANCEMENT
 
-Documentation for L<xml_to_db> now includes sample output.
+The option B<-j> is now a synonym for B<--parallelism>.
+(And several documention bugs about this option are fixed.)
 
-=item NEW
+=item ENHANCEMENT
 
-L<yaml_to_db> converts a specific form of YAML to fsdb.
+Additional support for C<--header> in L<dbcolmerge>, L<dbcol>, L<dbrow>,
+and L<dbroweval>.
 
 =item BUG FIX
 
-The test suite now uses C<diff -c -b> rather than C<diff -cb>
-to make OpenBSD-5.9 happier, I hope.
+Version 2.62 was supposed to have this improvement, but did not (and now does):
+L<dbfilepivot> now allows the B<--possible-pivots> option,
+and if it is provided processes the data in one pass.
 
-=item ENHANCEMENT
+=item BUG FIX
 
-Comments that log operations at the end of each file now do simple
-quoting of spaces.  (It is not guaranteed to be fully shell-compliant.)
-
-=item ENHANCEMENT
-
-There is a new standard option, C<--header>,
-allowing one to specify an Fsdb header for inputs that lack it.
-Currently it is supported by L<dbcoldefine>,
-L<dbrowuniq>, L<dbmapreduce>, L<dbmultistats>, L<dbsort>,
-L<dbpipeline>.
+Version 2.62 was supposed to have this improvement, but did not (and now does):
+L<dbroweval> logs are now quoted.
 
 =back
 
@@ -3383,6 +3378,48 @@ no one but me ever used that version.)
 
 =back
 
+=head2 2.62, 2016-11-29
+A new L<yaml_to_db> and other minor improvements.
+
+=over 4
+
+=item ENHANCEMENT
+
+Documentation for L<xml_to_db> now includes sample output.
+
+=item NEW
+
+L<yaml_to_db> converts a specific form of YAML to fsdb.
+
+=item BUG FIX
+
+The test suite now uses C<diff -c -b> rather than C<diff -cb>
+to make OpenBSD-5.9 happier, I hope.
+
+=item ENHANCEMENT
+
+Comments that log operations at the end of each file now do simple
+quoting of spaces.  (It is not guaranteed to be fully shell-compliant.)
+
+=item ENHANCEMENT
+
+There is a new standard option, C<--header>,
+allowing one to specify an Fsdb header for inputs that lack it.
+Currently it is supported by L<dbcoldefine>,
+L<dbrowuniq>, L<dbmapreduce>, L<dbmultistats>, L<dbsort>,
+L<dbpipeline>.
+
+=item ENHANCEMENT
+
+L<dbfilepivot> now allows the B<--possible-pivots> option,
+and if it is provided processes the data in one pass.
+
+=item ENHANCEMENT
+
+L<dbroweval> logs are now quoted.
+
+=back
+
 =head1 AUTHOR
 
 John Heidemann, C<johnh@isi.edu>
