@@ -68,6 +68,11 @@ but Fsdb::Filter objects in Perl do not run until you invoke
 the run() method.
 The C<--(no)autorun> option controls that behavior within Perl.
 
+=item B<--header H>
+
+Use H as the full Fsdb header, rather than reading a header from
+then input.
+
 =item B<--help>
 
 Show help.
@@ -170,6 +175,7 @@ sub set_defaults ($) {
     $self->SUPER::set_defaults();
     $self->{_elem_separator} = '_';
     $self->{_merge_columns} = [];
+    $self->{_header} = undef;
 }
 
 =head2 parse_options
@@ -193,6 +199,7 @@ sub parse_options ($@) {
 	'C|element-separator=s' => \$self->{_elem_separator},
 	'd|debug+' => \$self->{_debug},
 	'e|empty=s' => \$self->{_empty},
+	'header=s' => \$self->{_header},
 	'i|input=s' => sub { $self->parse_io_option('input', @_); },
 	'log!' => \$self->{_logprog},
 	'o|output=s' => sub { $self->parse_io_option('output', @_); },
@@ -218,7 +225,9 @@ sub setup ($) {
     croak $self->{_prog} . ": no columns to merge selected.\n"
 	if ($#{$self->{_merge_columns}} == -1);
 
-    $self->finish_io_option('input', -comment_handler => $self->create_pass_comments_sub);
+    my(@finish_args) = (-comment_handler => $self->create_pass_comments_sub);
+    push (@finish_args, -header => $self->{_header}) if (defined($self->{_header}));
+    $self->finish_io_option('input', @finish_args);
 
     $self->finish_io_option('output', -clone => $self->{_in}, -outputheader => 'delay');
     $self->{_merged_colname} = join($self->{_elem_separator}, @{$self->{_merge_columns}});
