@@ -94,7 +94,7 @@ Assume data is already sorted.
 With one -S, we check and confirm this precondition.
 When repeated, we skip the check.
 
-=item <--parallelism=N>
+=item B<--parallelism=N> or C<-j N>
 
 Allow sorting to happen in parallel.
 Defaults on.
@@ -312,11 +312,11 @@ sub parse_options($@) {
 	'f|format=s' => \$self->{_format},
 	'F|fs|cs|fieldseparator|columnseparator=s' => \$self->{_fscode},
 	'i|input=s' => sub { $self->parse_io_option('input', @_); },
+	'j|parallelism=i' => \$self->{_max_parallelism},
 	'k|key=s' => \$self->{_key_column},
 	'log!' => \$self->{_logprog},
 	'm|median!' =>  \$self->{_median},
 	'o|output=s' => sub { $self->parse_io_option('output', @_); },
-	'parallelism=i' => \$self->{_max_parallelism},
 	'q|quantile=i' => \$self->{_quantile},
 	's|sample!' =>  \$self->{_sample},
 	'S|pre-sorted+' => \$self->{_pre_sorted},
