@@ -169,7 +169,7 @@ Change the field separator of a
 non-multi-key-aware reducers to match the input's field separator.
 Not done by default.
 
-=item <--parallelism=N>
+=item B<--parallelism=N> or B<-j N>
 
 Allow up to N reducers to run in parallel.
 Default is the number of CPUs in the machine.
@@ -464,6 +464,7 @@ sub parse_options ($@) {
 	'f|code-files=s@' => $self->{_code_files},
 	'header=s' => \$self->{_header},
 	'i|input=s' => sub { $self->parse_io_option('input', @_); },
+	'j|parallelism=i' => \$self->{_max_parallelism},
 	'k|key=s' => \$self->{_key_column},
 	'K|pass-current-key!' => \$self->{_pass_current_key},
 	'prepend-key' => sub { $self->{_prepend_key} = 1; },
@@ -471,7 +472,6 @@ sub parse_options ($@) {
 	'log!' => \$self->{_logprog},
 	'M|multiple-ok!' => \$self->{_reducer_is_multikey_aware},
 	'o|output=s' => sub { $self->parse_io_option('output', @_); },
-	'parallelism=i' => \$self->{_max_parallelism},
 	'S|pre-sorted+' => \$self->{_pre_sorted},
 	'test-parallelism!' => \$self->{_test_parallelism},  # for test suite only
 	'T|tmpdir|tempdir=s' => \$self->{_tmpdir},
