@@ -90,7 +90,7 @@ Assume data is already sorted.
 With one -S, we check and confirm this precondition.
 When repeated, we skip the check.
 
-=item <-T TmpDir>
+=item B<-T TmpDir>
 
 where to put temporary data.
 Only used if median or quantiles are requested.
@@ -98,7 +98,7 @@ Also uses environment variable TMPDIR, if -T is
 not specified.
 Default is /tmp.
 
-=item <--parallelism=N>
+=item B<--parallelism=N> or B<-j N>
 
 Allow up to N reducers to run in parallel.
 Default is the number of CPUs in the machine.
@@ -260,11 +260,11 @@ sub parse_options ($@) {
 	'f|format=s' => \$self->{_format},
 	'header=s' => \$self->{_header},
 	'i|input=s' => sub { $self->parse_io_option('input', @_); },
+	'j|parallelism=i' => \$self->{_max_parallelism},
 	'k|key=s' => \$self->{_key_column},
 	'log!' => \$self->{_logprog},
 	'm|median!' =>  \$self->{_median},
 	'o|output=s' => sub { $self->parse_io_option('output', @_); },
-	'parallelism=i' => \$self->{_max_parallelism},
 	'q|quantile=i' => \$self->{_quantile},
 	'S|pre-sorted+' => \$self->{_pre_sorted},
 	'T|tmpdir|tempdir=s' => \$self->{_tmpdir},
