@@ -106,6 +106,11 @@ but Fsdb::Filter objects in Perl do not run until you invoke
 the run() method.
 The C<--(no)autorun> option controls that behavior within Perl.
 
+=item B<--header> H
+
+Use H as the full Fsdb header, rather than reading a header from
+then input.
+
 =item B<--help>
 
 Show help.
@@ -324,6 +329,7 @@ sub set_defaults ($) {
     $self->{_code_files} = [];
     $self->{_code_lines} = [];
     $self->{_warnings} = undef;
+    $self->{_header} = undef;
 
     $self->{_no_output} = undef;
     $self->{_no_output_even_comments} = undef;
@@ -361,6 +367,7 @@ sub parse_options ($@) {
 	'd|debug+' => \$self->{_debug},
 	'e|end=s@' => $self->{_end_code},
 	'f|code-files=s@' => $self->{_code_files},
+	'header=s' => \$self->{_header},
 	'i|input=s' => sub { $self->parse_io_option('input', @_); },
 	'log!' => \$self->{_logprog},
 	'm|manual-output' => \$self->{_manual_output}, 
@@ -407,6 +414,7 @@ sub setup ($) {
     };
     push(@in_options, (-comment_handler => $self->create_pass_comments_sub))
 	if (!$self->{_no_output_even_comments});
+    push(@in_options, -header => $self->{_header}) if (defined($self->{_header}));
     $self->finish_io_option('input', @in_options);
     my $read_fastpath_sub = $self->{_in}->fastpath_sub();
 
@@ -428,15 +436,15 @@ sub setup ($) {
 	 $any_needs_lfref = 1 if ($this_needs_lfref);
 	 my($code) = join("\n", @{$iref->[$DB_CODE_A_F]});
 	 $any_needs_lfref = 1 if ($code =~ /lfref/);
-	 $self->{_pretty_args} .= " $iref->[$COMMAND_F] { " .
-			Fsdb::Support::code_prettify(@{$iref->[$DB_CODE_A_F]}) . " }";
+	 $self->{_pretty_args} .= " $iref->[$COMMAND_F] " .  
+			Fsdb::Support::shell_quote("{ " . Fsdb::Support::code_prettify(@{$iref->[$DB_CODE_A_F]}) . " }");
 	 print STDERR "$iref->[$TITLE_F]:\n$c\n" if ($self->{_debug});
     };
     exit 1 if ($self->{_debug} == 1);
 
     #
     # write the loop
-    # xxx: should be able to otpimize away $lfref
+    # xxx: should be able to optimize away $lfref
     #
     {
 	my $loop_sub;
@@ -536,8 +544,7 @@ Override compute_program_log to do pretty-printed arguments.
 sub compute_program_log($) {
     my $self = shift @_;
 
-    my $log = "  | " . $self->{_prog} .
-				" " . $self->{_pretty_args};
+    my $log = " | " . $self->{_prog} . $self->{_pretty_args};
     return $log;
 }
 
